@@ -10,7 +10,7 @@ if [ "$1" == "i" ]; then
     export FREETYPE_DIR=""
     export FREEIMAGE_DIR=""
     export TBB_DIR=""
-    export VTK_DIR=""
+    export VTK_DIR="${THIRDPARTY_DIR}/lib64"
     export FFMPEG_DIR=""
     export JEMALLOC_DIR=""
 
